function [dd, dat] = get_dataset(provider,dataset, varargin)
if numel(varargin) > 0
    options = parse_options(varargin);
else
    options = ['?limit=1000&offset=0&q=&observations=1&align_periods=1&' ...
               'dimensions={}'];
end
default_api_base_url = 'https://api.db.nomics.world/v22/series/';
url = join([default_api_base_url, provider, '/', dataset, options]);
dat = webread(join(url));
docs = dat.series.docs;
nseries = dat.dataset.nb_series;
nrow = 1;
for id = 1:nseries
    nrow = nrow + length(docs(id).period);
end
dimensions_codes = dat.dataset.dimensions_codes_order;
ndim = length(dimensions_codes);
ncol = ndim + 10;
dd = cell(nrow,ncol);
dd{1,1} = '@frequency';
dd{1,2} = 'dataset_code';
dd{1,3} = 'dataset_name';
dd{1,4} = 'indexed_at';
dd{1,5} = 'original_period';
dd{1,6} = 'period';
dd{1,7} = 'provider_code';
dd{1,8} = 'series_code';
dd{1,9} = 'series name';
dd{1,10} = 'value';
for i = 1:ndim
    dd{1,10+i} = dimensions_codes{i};
end

row = 2;
for i = 1:nseries
    doc = docs(i);
    x_frequency = doc.x_frequency;
    dataset_code = doc.dataset_code;
    dataset_name = doc.dataset_name;
    series_code = doc.series_code;
    series_name = doc.series_name;
    indexed_at = doc.indexed_at;
    provider_code = doc.provider_code;
    dimensions = doc.dimensions;
    period = doc.period;
    period_start_day = doc.period_start_day;
    value = doc.value;
    for j = 1:length(period)
        dd{row,1} = x_frequency;
        dd{row,2} = dataset_code;
        dd{row,3} = dataset_name;
        dd{row,4} = indexed_at;
        dd{row,5} = period{j};
        dd{row,6} = period_start_day{j};
        dd{row,7} = provider_code;
        dd{row,8} = series_code;
        dd{row,9} = series_name;
        if iscell(value)
            dd{row,10} = value{j};
        else
            dd{row,10} = value(j);
        end
        for k = 1:ndim
            dim_code = dimensions.(dimensions_codes{k});
            dd{row,10+k} = dim_code;
        end
        row = row + 1;
    end
end

function options_str = parse_options(arguments)
i = 1;
options = struct();
options.limit = 1000;
options.dimensions = '{}';
options.mask = '';
while i <= length(arguments)
    if arguments{1} == 'limit'
        options.limit = arguments{2};
        i = i + 2;
    elseif arguments{1} == 'dimensions'
        if ~isempty(options.mask)
            error('rdb: you can''t use both option dimension and option mask');
        end
    elseif arguments =='mask'
        if options.dimensions ~= '{}'
            error('rdb: you can''t use both option dimension and option mask');
        end
        options.mask = arguments{2};
        i = i+2;
    else
        disp_usage();
    end
end

options_str = sprintf('?limit=%d0&q=&observations=1&align_periods=1&dimensions=%s',...
                      options.limit, options.dimensions);
if options.mask
    options_str = options_str + '&' + options.mask;
end